<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>A propos de Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Remerciements</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Accord de licence</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Lecteur Multimédia basé sur Qt (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="75"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Utilise Qt %1 (compilé avec Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 L&apos;équipe de développement de Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Transports:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Decoders:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="106"/>
        <source>Engines:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="117"/>
        <source>Effects:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="162"/>
        <source>File dialogs:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="175"/>
        <source>User interfaces:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="150"/>
        <source>Output plugins:</source>
        <translation>Plugins de sortie:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="129"/>
        <source>Visual plugins:</source>
        <translation>Plugins Visuels:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="140"/>
        <source>General plugins:</source>
        <translation>Plugins généraux:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Entrer l&apos;URL à ajouter</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="46"/>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="53"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="88"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>ColumnEditor</name>
    <message>
        <location filename="../forms/columneditor.ui" line="14"/>
        <source>Edit Column</source>
        <translation>Éditer la colonne</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="36"/>
        <source>Name:</source>
        <translation>Nom&#xa0;:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="76"/>
        <source>Format:</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="64"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="29"/>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="85"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="86"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="90"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="93"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="94"/>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="95"/>
        <source>Composer</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="96"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="101"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="100"/>
        <source>Track Index</source>
        <translation>Index de piste</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="87"/>
        <source>Artist - Album</source>
        <translation>Artiste - Album</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="88"/>
        <source>Artist - Title</source>
        <translation>Artiste - Titre</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="89"/>
        <source>Album Artist</source>
        <translation>Artiste d&apos;album</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="91"/>
        <source>Track Number</source>
        <translation>Numéro de piste</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="92"/>
        <source>Two-digit Track Number</source>
        <translation>Numéro de piste à deux chiffres</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="97"/>
        <source>Disc Number</source>
        <translation>Numéro de disque</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="98"/>
        <source>File Name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="99"/>
        <source>File Path</source>
        <translation>Chemin du fichier</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="102"/>
        <source>Parent Directory Name</source>
        <translation>Nom du Répertoire Parent</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="103"/>
        <source>Parent Directory Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="104"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Paramètres de Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Connectivité</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="854"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Donnée meta</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <source>Convert %20 to blanks</source>
        <translation>Convertir %20 vers espaces vierge</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="129"/>
        <source>Load metadata from files</source>
        <translation>Charger données metas depuis des fichiers</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="136"/>
        <source>Convert underscores to blanks</source>
        <translation>Convertir les underscores en espaces vierges</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="150"/>
        <source>Group format:</source>
        <translation>Format du groupe</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="160"/>
        <location filename="../forms/configdialog.ui" line="583"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="170"/>
        <source>Read tags while loading a playlist</source>
        <translation>Lire les tags durant la lecture d&apos;une playlist</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="180"/>
        <source>Directory Scanning Options</source>
        <translation>Options du scan des répertoires</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="186"/>
        <source>Restrict files to:</source>
        <translation>Restreindre les fichiers à:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="196"/>
        <location filename="../forms/configdialog.ui" line="461"/>
        <source>Exclude files:</source>
        <translation>Exclure les fichiers:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="209"/>
        <source>Miscellaneous</source>
        <translation>Divers</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Auto-save playlist when modified</source>
        <translation>Sauvegarder automatiquement la playlist quand modifiée</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="222"/>
        <source>Clear previous playlist when opening new one</source>
        <translation>Nettoyer la playlist précédente lorsqu&apos; une nouvelle est ouverte</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="229"/>
        <source>Skip already existing tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="277"/>
        <location filename="../configdialog.cpp" line="334"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="290"/>
        <location filename="../configdialog.cpp" line="337"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="332"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Filename</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="349"/>
        <source>Look and Feel</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="355"/>
        <source>Language:</source>
        <translation>Langage:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="388"/>
        <source>Display average bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="398"/>
        <source>Playback</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="404"/>
        <source>Continue playback on startup</source>
        <translation>Continuer la lecture au démarrage</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="411"/>
        <source>Determine file type by content</source>
        <translation>Déterminer le type de fichier par son contenu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="418"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Ajouter des fichiers à la playlist par ligne de commande</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="435"/>
        <source>Cover Image Retrieve</source>
        <translation>Récupérer les pochettes d&apos;albums</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="441"/>
        <source>Use separate image files</source>
        <translation>Utiliser des fichiers d&apos;images séparés</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="451"/>
        <source>Include files:</source>
        <translation>Inclure les fichiers:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="473"/>
        <source>Recursive search depth:</source>
        <translation>Recherche récursive profonde:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="505"/>
        <source>URL Dialog</source>
        <translation>Fenêtre d&apos;URL</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>Coller automatiquement l&apos;URL provenant du presse papier</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="521"/>
        <source>CUE Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="527"/>
        <source>Use system font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="548"/>
        <source>Font:</source>
        <translation>Police&#xa0;:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="612"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="624"/>
        <source>Enable proxy usage</source>
        <translation>Activer l&apos;usage du proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="631"/>
        <source>Proxy type:</source>
        <translation>Type de proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="641"/>
        <source>Proxy host name:</source>
        <translation>Nom d&apos;hôte du Proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="654"/>
        <source>Proxy port:</source>
        <translation>Port du proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="667"/>
        <source>Use authentication with proxy</source>
        <translation>Utiliser l&apos;authentification avec le proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="674"/>
        <source>Proxy user name:</source>
        <translation>Nom d&apos;utilisateur du proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="687"/>
        <source>Proxy password:</source>
        <translation>Mot de passe du proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="724"/>
        <source>Replay Gain</source>
        <translation>Rejouer Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="730"/>
        <source>Replay Gain mode:</source>
        <translation>Rejouer le mode Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Preamp:</source>
        <translation>Préampli</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="779"/>
        <location filename="../forms/configdialog.ui" line="824"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="792"/>
        <source>Default gain:</source>
        <translation>Gain par défaut:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="844"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Prévenir les coupure en utilisant l&apos;info du peak</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="860"/>
        <source>Buffer size:</source>
        <translation>Taille du tampon</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="886"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="919"/>
        <source>Use software volume control</source>
        <translation>Utiliser le contrôle logiciel du volume</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="959"/>
        <source>Use two passes for equalizer</source>
        <translation>Utiliser deux passes pour l&apos;égalisateur</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="902"/>
        <source>Volume adjustment step:</source>
        <translation>Ajustement du volume par palier:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="926"/>
        <source>Output bit depth:</source>
        <translation>Profondeur (bit) de sortie:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <source>Use dithering</source>
        <translation>Utiliser le dithering</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="66"/>
        <source>Track</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <source>Disabled</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="89"/>
        <source>File Types</source>
        <translation>Type de fichier</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="206"/>
        <source>Transports</source>
        <translation>Transports</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="217"/>
        <source>Decoders</source>
        <translation>Décodeurs</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="228"/>
        <source>Engines</source>
        <translation>Moteurs</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="240"/>
        <source>Effects</source>
        <translation>Effets</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="251"/>
        <source>Visualization</source>
        <translation>Visualisation</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="263"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="274"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>File Dialogs</source>
        <translation>Fenêtres de fichier</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>User Interfaces</source>
        <translation>Interfaces utilisateur</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="347"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;Autodétection&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="348"/>
        <source>Brazilian Portuguese</source>
        <translation>Brésilien Portugais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="349"/>
        <source>Chinese Simplified</source>
        <translation>Chinois Simplifié</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="350"/>
        <source>Chinese Traditional</source>
        <translation>Chinois Traditionnel</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="351"/>
        <source>Czech</source>
        <translation>Tchèque</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="352"/>
        <source>Dutch</source>
        <translation>Hollandais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="353"/>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="354"/>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="355"/>
        <source>Galician</source>
        <translation>Galicien</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="356"/>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="357"/>
        <source>Greek</source>
        <translation>Grec</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="358"/>
        <source>Hebrew</source>
        <translation>Hébreu</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="359"/>
        <source>Hungarian</source>
        <translation>Hongrois</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="360"/>
        <source>Indonesian</source>
        <translation>Indonésien</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="361"/>
        <source>Italian</source>
        <translation>Italien</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="362"/>
        <source>Japanese</source>
        <translation>Japonais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="363"/>
        <source>Kazakh</source>
        <translation>Kazakh</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="364"/>
        <source>Korean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="365"/>
        <source>Lithuanian</source>
        <translation>Lituanien</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Polish</source>
        <translation>Polonais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="367"/>
        <source>Portuguese</source>
        <translation>Portugais</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="368"/>
        <source>Russian</source>
        <translation>Russe</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="369"/>
        <source>Serbian</source>
        <translation>Serbe</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="370"/>
        <source>Slovak</source>
        <translation>Slovaque</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="371"/>
        <source>Swedish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Spanish</source>
        <translation>Espagnol</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="373"/>
        <source>Turkish</source>
        <translation>Turque</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="374"/>
        <source>Ukrainian</source>
        <translation>Ukrainien</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="375"/>
        <source>Serbian (Ijekavian)</source>
        <translation>Serbe (Ijekavien)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="376"/>
        <source>Serbian (Ekavian)</source>
        <translation>Serbe (Ekavien)</translation>
    </message>
</context>
<context>
    <name>CoverEditor</name>
    <message>
        <location filename="../forms/covereditor.ui" line="22"/>
        <source>Image source:</source>
        <translation>Source de l&apos;image:</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="76"/>
        <source>Load</source>
        <translation>Charger</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="83"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../forms/covereditor.ui" line="90"/>
        <source>Save as...</source>
        <translation>Enregistrer sous ...</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="33"/>
        <source>External file</source>
        <translation>Fichier externe</translation>
    </message>
    <message>
        <location filename="../covereditor.cpp" line="34"/>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>CoverViewer</name>
    <message>
        <location filename="../coverviewer.cpp" line="35"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Enregistrer sous…</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="68"/>
        <source>Save Cover As</source>
        <translation>Enregistrer la couverture sous…</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="70"/>
        <location filename="../coverviewer.cpp" line="83"/>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <location filename="../coverviewer.cpp" line="81"/>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
</context>
<context>
    <name>CueEditor</name>
    <message>
        <location filename="../forms/cueeditor.ui" line="40"/>
        <source>Load</source>
        <translation>Charger</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="47"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../forms/cueeditor.ui" line="54"/>
        <source>Save as...</source>
        <translation>Enregistrer sous ...</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="131"/>
        <source>Open CUE File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="133"/>
        <location filename="../cueeditor.cpp" line="152"/>
        <source>CUE Files</source>
        <translation>Fichiers .cue</translation>
    </message>
    <message>
        <location filename="../cueeditor.cpp" line="150"/>
        <source>Save CUE File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="44"/>
        <source>Open the directory containing this file</source>
        <translation>Ouvrir le repértoire contenant ce fichier</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="63"/>
        <source>Summary</source>
        <translation>Sommaire</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="206"/>
        <source>%1/%2</source>
        <translation>%1%2</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="258"/>
        <source>Cover</source>
        <translation>Couverture</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="284"/>
        <source>Lyrics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="304"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="305"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="306"/>
        <source>Album artist</source>
        <translation>Artiste de l&apos;album</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="307"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="308"/>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="309"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="310"/>
        <source>Composer</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="311"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="312"/>
        <source>Track</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="313"/>
        <source>Disc number</source>
        <translation>Numéro du disque</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="331"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="334"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="334"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="335"/>
        <source>Sample rate</source>
        <translation>Taux de sample</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="335"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="336"/>
        <source>Channels</source>
        <translation>Canaux</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>Sample size</source>
        <translation>Taille d&apos;échantillonage</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="337"/>
        <source>bits</source>
        <translation>bits</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="338"/>
        <source>Format name</source>
        <translation>Nom du format</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="339"/>
        <source>File size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="339"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="383"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="383"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Sauter à la piste</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="46"/>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="85"/>
        <location filename="../jumptotrackdialog.cpp" line="122"/>
        <location filename="../jumptotrackdialog.cpp" line="153"/>
        <source>Queue</source>
        <translation>Queue</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="104"/>
        <source>Jump To</source>
        <translation>Sauter à</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="98"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="99"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="120"/>
        <location filename="../jumptotrackdialog.cpp" line="151"/>
        <source>Unqueue</source>
        <translation>Enlever de la queue</translation>
    </message>
</context>
<context>
    <name>MetaDataFormatterMenu</name>
    <message>
        <location filename="../metadataformattermenu.cpp" line="26"/>
        <source>Artist</source>
        <translation>Artiste</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="27"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="28"/>
        <source>Album Artist</source>
        <translation>Artiste d&apos;album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="31"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="32"/>
        <source>Track Number</source>
        <translation>Numéro de piste</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="33"/>
        <source>Two-digit Track Number</source>
        <translation>Numéro de piste à deux chiffres</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="37"/>
        <source>Track Index</source>
        <translation>Index de piste</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="39"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="40"/>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="41"/>
        <source>Composer</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="46"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="57"/>
        <source>Parent Directory Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="59"/>
        <source>Bitrate</source>
        <translation>Taux de bit</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="60"/>
        <source>Sample Rate</source>
        <translation>Taux d’échantillonnage</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="61"/>
        <source>Number of Channels</source>
        <translation>Nombre de canaux</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="62"/>
        <source>Sample Size</source>
        <translation>Taille d’échantillonnage</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="63"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="64"/>
        <source>Decoder</source>
        <translation>Décodeur</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="67"/>
        <source>File Size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="42"/>
        <source>Disc Number</source>
        <translation>Numéro de disque</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="47"/>
        <source>File Name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="48"/>
        <source>File Path</source>
        <translation>Chemin du fichier</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="43"/>
        <source>Year</source>
        <translation>Année</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="50"/>
        <source>Condition</source>
        <translation>Condition</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="49"/>
        <source>Artist - Title</source>
        <translation>Artiste - Titre</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="54"/>
        <source>Artist - [Year] Album</source>
        <translation>Artiste - [Année] Album</translation>
    </message>
    <message>
        <location filename="../metadataformattermenu.cpp" line="56"/>
        <source>Parent Directory Name</source>
        <translation>Nom du Répertoire Parent</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="123"/>
        <source>Unsupported playlist format</source>
        <translation>Format de playlist non supporté</translation>
    </message>
</context>
<context>
    <name>PlayListHeaderModel</name>
    <message>
        <location filename="../playlistheadermodel.cpp" line="35"/>
        <source>Artist - Title</source>
        <translation>Artiste - Titre</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="185"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="186"/>
        <source>Add Column</source>
        <translation>Ajouter une colonne</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="181"/>
        <location filename="../playlistmanager.cpp" line="327"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
</context>
<context>
    <name>PlayListTrack</name>
    <message>
        <location filename="../playlisttrack.cpp" line="245"/>
        <source>Streams</source>
        <translation>Streams</translation>
    </message>
    <message>
        <location filename="../playlisttrack.cpp" line="250"/>
        <source>Empty group</source>
        <translation>Groupe vide</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="59"/>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="35"/>
        <source>Qt File Dialog</source>
        <translation>Fenêtre de fichier Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Editeur de tag</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Titre:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Artiste:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Album artist:</source>
        <translation>Artiste de l&apos;album:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="123"/>
        <source>Composer:</source>
        <translation>Compositeur:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="143"/>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="169"/>
        <source>Track:</source>
        <translation>Piste:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="190"/>
        <location filename="../forms/tageditor.ui" line="228"/>
        <location filename="../forms/tageditor.ui" line="260"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="203"/>
        <source>Year:</source>
        <translation>Année:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="250"/>
        <source>Disc number:</source>
        <translation>Numéro de disque:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="275"/>
        <source>Comment:</source>
        <translation>Commentaire:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="311"/>
        <source>Include selected tag in file</source>
        <translation>Inclure le tag sélectionné dans le fichier</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Editeur de template</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Rétablir</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Insérer</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="138"/>
        <location filename="../uihelper.cpp" line="150"/>
        <source>All Supported Bitstreams</source>
        <translation>Tous les Bitstreams supportés</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="144"/>
        <source>Select one or more files to open</source>
        <translation>Sélectionner un fichier ou plus à ouvrir</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="156"/>
        <source>Select one or more files to play</source>
        <translation>Sélectionner un fichier ou plus à jouer</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Choose a directory</source>
        <translation>Choisissez un répertoire</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="180"/>
        <location filename="../uihelper.cpp" line="206"/>
        <source>Playlist Files</source>
        <translation>Fichiers de playlist</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="182"/>
        <source>Open Playlist</source>
        <translation>Ouvrir une playlist</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="209"/>
        <location filename="../uihelper.cpp" line="228"/>
        <source>Save Playlist</source>
        <translation>Sauvegarder la playlist</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="228"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 existe déjà.
Voulez-vous le remplacer&#xa0;?</translation>
    </message>
</context>
<context>
    <name>WinFileAssocPage</name>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="17"/>
        <source>Media files handled by Qmmp:</source>
        <translation>Fichiers multimédias pris en charge par Qmmp:</translation>
    </message>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="49"/>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="109"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="110"/>
        <source>Not all files could be associated. Please check your security permissions and retry.</source>
        <translation>Tous les fichiers ne peuvent être associés. Merci de vérifier vos permissions de sécurité et réessayer.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="117"/>
        <source>Check all file types in the list</source>
        <translation>Cocher tous les types de fichier dans la liste</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="118"/>
        <source>Check the media file extensions you would like Qmmp to handle. When you click Apply, the checked files will be associated with Qmmp. If you uncheck a media type, the file association will be restored.</source>
        <translation>Cocher les fichiers d&quot;extensions multimédias que vous voulez que Qmmp prenne en charge. Lorsque vous cliquez sur Appliquer, les fichiers cochés vont être associés avec Qmmp. Si vous décocher un type de média, l&apos;association de fichier sera restauré.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="122"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Restoration doesn&apos;t work on Windows Vista/7.</source>
        <translation>&lt;b&gt;Note:&lt;/b&gt; La réstauration ne fonctionne pas sur Windows Vista/7</translation>
    </message>
</context>
</TS>
